==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/pt-BR/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Categorias de Ativos',
    'category_name'  					=> 'Nome da Categoria',
    'checkin_email'                     => 'Enviar email para o usuário no check-in / check-out.',
    'checkin_email_notification'        => 'Este usuário receberá um email no checkin / checkout.',
    'clone'                             => 'Clonar Categoria',
    'create'  							=> 'Criar Categoria',
    'edit'                              => 'Editar Categoria',
    'email_will_be_sent_due_to_global_eula' => 'Um email será enviado ao usuário porque o EULA global está sendo utilizado.',
    'email_will_be_sent_due_to_category_eula' => 'Um email será enviado para o usuário porque um EULA foi definido para essa categoria.',
    'eula_text'							=> 'EULA da Categoria',
    'eula_text_help'					=> 'Este campo lhe permite personalizar seus EULAs para tipos específicos de bens. Se você apenas tem um EULA para todos os seus bens, você pode selecionar a caixa abaixo para usar o padrão primário.',
    'name'                              => 'Nome da Categoria',
    'require_acceptance'				=> 'Requer que usuários confirmem a aceitação de ativos nesta categoria.',
    'required_acceptance'				=> 'Este usuário receberá um e-mail com um link para confirmar a aceitação deste item.',
    'required_eula'						=> 'Este usuário receberá um e-mail com uma cópia do EULA',
    'no_default_eula'					=> 'Nenhum EULA padrão primário foi encontrado. Adicione um nas Configurações.',
    'update'  							=> 'Atualizar Categoria',
    'use_default_eula'					=> 'Em vez disso, use o <a href="#" data-toggle="modal" data-target="#eulaModal">EULA padrão primário</a>.',
    'use_default_eula_disabled'			=> '<del>Em vez disso, use o EULA padrão primário.</del> Nenhum EULA padrão primário foi definido. Adicione um nas Configurações.',
    'use_default_eula_column'			=> 'Usar padrão EULA',

);

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/pt-BR/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Categorias de Ativos',
    'category_name'  					=> 'Nome da Categoria',
    'checkin_email'                     => 'Enviar email para o usuário na devolução / saída.',
    'email_to_initiator'                => 'Envie um e-mail para você quando o usuário aceitar ou recusar o pagamento.',
    'checkin_email_notification'        => 'Este usuário receberá um email no checkin / checkout.',
    'clone'                             => 'Clonar Categoria',
    'create'  							=> 'Criar Categoria',
    'edit'                              => 'Editar Categoria',
    'email_will_be_sent_due_to_global_eula' => 'Um email será enviado ao usuário porque o EULA global está sendo utilizado.',
    'email_will_be_sent_due_to_category_eula' => 'Um email será enviado para o usuário porque um EULA foi definido para essa categoria.',
    'eula_text'							=> 'EULA da Categoria',
    'eula_text_help'					=> 'Este campo lhe permite personalizar seus EULAs para tipos específicos de bens. Se você apenas tem um EULA para todos os seus bens, você pode selecionar a caixa abaixo para usar o padrão primário.',
    'name'                              => 'Nome da Categoria',
    'require_acceptance'				=> 'Requer que usuários confirmem a aceitação de ativos nesta categoria.',
    'required_acceptance'				=> 'Este usuário receberá um e-mail com um link para confirmar a aceitação deste item.',
    'required_eula'						=> 'Este usuário receberá um e-mail com uma cópia do EULA',
    'no_default_eula'					=> 'Nenhum EULA padrão primário foi encontrado. Adicione um nas Configurações.',
    'update'  							=> 'Atualizar Categoria',
    'use_default_eula'					=> 'Em vez disso, use o <a href="#" data-toggle="modal" data-target="#eulaModal">EULA padrão primário</a>.',
    'use_default_eula_disabled'			=> '<del>Em vez disso, use o EULA padrão primário.</del> Nenhum EULA padrão primário foi definido. Adicione um nas Configurações.',
    'use_default_eula_column'			=> 'Usar padrão EULA',
    'import_require_acceptance'         => 'Requerer Aceitação',
    'import_checkin_email'              => 'Enviar e-mail de Checkin',
    'import_eula_text'                  => 'Texto do EULA',
    'import_category_type'              => 'Tipo de Categoria',

);
